@@ -1,5 +1,5 @@
 package Object::eBay::ListingDetails;
-our $VERSION = '0.1.0';
+our $VERSION = '0.2.0';
 
 use Class::Std; {
     use warnings;
@@ -13,22 +13,41 @@ use Class::Std; {
 
     __PACKAGE__->simple_attributes(qw{
         EndTime
+        StartTime
     });
 
+    __PACKAGE__->complex_attributes({
+        BuyItNowAvailable => {  # we'll wrap this in is_buy_it_now_available
+            class => 'Boolean',
+        }
+    });
+
+    # this is necessary because BuyItNowAvailable is missing
+    # if the BIN price is 0
+    sub is_buy_it_now_available {
+        my ($self) = @_;
+        my $answer = eval { $self->buy_it_now_available };
+        my $exception = $@;
+        return $answer if not $exception;
+
+        if ( $exception =~ m/Can't find 'BuyItNowAvailable' via/ ) {
+            return Object::eBay::Boolean->new({
+                object_details => 'false',
+            });
+        }
+        die $exception;  # rethrow the exception
+    }
+
     sub end_datetime {
         my ($self) = @_;
         my $iso = $self->end_time or die "EndTime was unavailable\n";
-        require DateTime;
-        my ($y, $m, $d, $h, $min, $s) = split /[-T:.]/, $iso;
-        return DateTime->new(
-            year      => $y,
-            month     => $m,
-            day       => $d,
-            hour      => $h,
-            minute    => $min,
-            second    => $s,
-            time_zone => 'UTC',
-        );
+        return $self->_make_datetime($iso);
+    }
+
+    sub start_datetime {
+        my ($self) = @_;
+        my $iso = $self->start_time or die "StartTime was unavailable\n";
+        return $self->_make_datetime($iso);
     }
 }
 
@@ -65,7 +84,29 @@ package installed.
 =head2 end_time
 
 Returns an ISO8601 formatted string indicating the UTC time that the item
-ends.
+is scheduled to end.  If the item has ended, it indicates the time when
+the item ended.
+
+=head2 is_buy_it_now_available
+
+Returns an L<Object::eBay::Boolean> object indicating whether or not
+this auction has buy it now available at the moment.  An auction might
+be listed with a Buy It Now price but once a bid is placed, Buy It Now
+is no longer available.  There are some other business rules which
+might affect whether or not Buy It Now is available.  See
+L<http://xrl.us/dwo72> for some details.
+
+=head2 start_datetime
+
+Similar to L</start_time> except it returns a L<DateTime> object.
+If this method is invoked, you must have a version of the L<DateTime>
+package installed.
+
+=head2 start_time
+
+Returns an ISO8601 formatted string indicating the UTC time that the item
+started.
+
 
 =head1 DIAGNOSTICS
 
